@@ -11,6 +11,9 @@
 #define __kplugintrader_h__
 
 #include "kplugininfo.h"
+
+#if KSERVICE_ENABLE_DEPRECATED_SINCE(5, 82)
+
 class KPluginTraderPrivate;
 /**
  * \class KPluginTrader kplugintrader.h <KPluginTrader>
@@ -141,7 +144,9 @@ public:
      *
      * @return A list of services that satisfy the query
      * @see http://techbase.kde.org/Development/Tutorials/Services/Traders#The_KTrader_Query_Language
+     * @deprecated since 5.82, use KPluginLoader::findPlugins.
      */
+    KSERVICE_DEPRECATED_VERSION(5, 82, "Use KPluginLoader::findPlugins")
     KPluginInfo::List query(const QString &subDirectory, const QString &serviceType = QString(), const QString &constraint = QString());
 
     /**
@@ -150,8 +155,11 @@ public:
      * You will need to use this to access the KPluginTrader functionality since the
      * constructors are protected.
      *
+     * @deprecated since 5.82, use KPluginLoader
+     *
      * @return Static KPluginTrader instance
      */
+    KSERVICE_DEPRECATED_VERSION(5, 82, "Use KPluginLoader")
     static KPluginTrader *self();
 
     /**
@@ -173,8 +181,10 @@ public:
      * @param error The string passed here will contain an error description.
      * @return A pointer to the newly created object or a null pointer if the
      *         factory was unable to create an object of the given type.
+     * @deprecated since 5.82, use KPluginLoader API.
      */
     template<class T>
+    KSERVICE_DEPRECATED_VERSION(5, 82, "Use KPluginLoader API")
     static T *createInstanceFromQuery(const QString &subDirectory,
                                       const QString &serviceType = QString(),
                                       const QString &constraint = QString(),
@@ -202,8 +212,10 @@ public:
      * @param error The string passed here will contain an error description.
      * @return A pointer to the newly created object or a null pointer if the
      *         factory was unable to create an object of the given type.
+     * @deprecated since 5.82, use KPluginLoader API.
      */
     template<class T>
+    KSERVICE_DEPRECATED_VERSION(5, 82, "Use KPluginLoader API")
     static T *createInstanceFromQuery(const QString &subDirectory,
                                       const QString &serviceType,
                                       const QString &constraint,
@@ -236,6 +248,7 @@ public:
         return nullptr;
     }
 
+    KSERVICE_DEPRECATED_VERSION(5, 82, "No users.")
     static void applyConstraints(KPluginInfo::List &lst, const QString &constraint);
 
 private:
@@ -250,5 +263,6 @@ private:
 
     KPluginTraderPrivate *const d;
 };
+#endif
 
 #endif
